/*
 * KAKASI (Kanji Kana Simple inversion program)
 * $Header: E2.c,v 2.0 92/07/18 12:06:56 takahasi Exp $
 * Copyright (C) 1992
 * Hironobu Takahashi (takahasi@tiny.or.jp)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either versions 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with KAKASI, see the file COPYING.  If not, write to the Free
 * Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/* $Log:	E2.c,v $
 * Revision 2.0  92/07/18  12:06:56  takahasi
 * *** empty log message ***
 * 
*/
#include "kakasi.h"

static void E2alphabet_copy(n, str, type)
     Character *n;
     char *str;
     int type;
{
    int i;

    for (i = 0; str[i] != '\0'; ++ i) {
	n[i].type = type;
	n[i].c1 = str[i];
    }
    n[i].type = OTHER;
    n[i].c1 = 0;
    n[i].c2 = 0;
}

static int E2alphabet(c, n, type)
     Character *c;
     Character *n;
     int type;
{
    static char E2alphabet_a1table[94][12] = {
	" ",",",".",",",".",".",":",";","?","!","\"","(maru)","'","`","..","~",
	"~","_","(kurikaesi)","(kurikaesi)","(kurikaesi)","(kurikaesi)","(kurikaesi)",
	"(kurikaesi)","(kurikaesi)","sime","(maru)","^","-","-","/","\\","~","||",
	"|","...","..","`","'","\"","\"","(",")","[","]","[","]","{","}","<",">",
	"<<",">>","(",")","(",")","(",")","+","-","+-","X","/","=","!=","<",">",
	"<=",">=","(kigou)","...","(osu)","(mesu)","(do)","'","\"","(Sessi)","\\",
	"$","(cent)","(fran)","%","#","&","*","@","(setu)","(hosi)","(hosi)","(maru)",
	"(maru)","(maru)","(diamond)" };
    static char E2greek_table[56][8] = {
	"Alpha", "Beta", "Gamma", "Delta", "Epsilon", "Zeta", "Eta", "Theta",
	"Iota", "Kappa", "Lambda", "Mu", "Nu", "Xi", "Omicron", "Pi", "Rho",
	"Sigma", "Tau", "Upsilon", "Phi", "Chi", "Psi", "Omega", 
	"", "", "", "", "", "", "", "", 
	"alpha", "beta", "gamma", "delta", "epsilon", "zeta", "eta", "theta",
	"iota", "kappa", "lambda", "mu", "nu", "xi", "omicron", "pi", "rho",
	"sigma", "tau", "upsilon", "phi", "chi", "psi", "omega"};

    switch(c[0].c1) { /* \266\350\244\264\244\310\244\313\275\350\315\375\244\362\312\254\263\344 */
      case 0xa1: /* 1\266\350\244\313\244\317\265\255\271\346\244\275\244\316\302\276\244\254\272\256\272\337\244\271\244\353\244\316\244\307\245\306\241\274\245\326\245\353\244\362\273\310\244\303\244\306\312\321\264\271 */
	if ((0xa1 <= c[0].c2) && (c[0].c2 < 0xa1 + 94)) {
	    E2alphabet_copy(n, E2alphabet_a1table[c[0].c2-0xa1], type);
	    return 1;
	} else {
	    E2alphabet_copy(n, "??", type);
	    return 1;
	}
      case 0xa2: /* 2\266\350\244\313\244\317\265\255\271\346\244\254\264\336\244\336\244\354\244\336\244\271\241\243\314\314\305\335\244\312\244\316\244\307\301\264\311\364 (kigou) \244\310\244\267\244\336\244\271 */
	E2alphabet_copy(n, "(kigou)", type);
	return 1;
      case 0xa3: /* 3\266\350\244\313\244\317\261\321\277\364\273\372\244\254\264\336\244\336\244\354\244\336\244\271\241\243\301\264\244\306\310\276\263\321\312\270\273\372\244\313\312\321\264\271\244\267\244\336\244\271 */
	n[0].type = type;
	n[0].c1 = c[0].c2 & 0x7f; /* \244\263\244\263\244\317\274\352\310\264\244\255\244\307\244\271\244\315\241\243\304\352\265\301\244\265\244\354\244\306\244\244\244\312\244\244\312\270\273\372\244\317\241\251 */
	n[1].type = OTHER;
	n[2].c1 = '\0';
	return 1;
      case 0xa4: /* \244\322\244\351\244\254\244\312 */
	return H2rom(c, n, type);
      case 0xa5: /* \245\253\245\277\245\253\245\312 */
	return K2rom(c, n, type);
      case 0xa6: /* 6\266\350\244\317\245\256\245\352\245\267\245\343\270\354\244\307\244\271 */
	if ((0xa1 <= c[0].c2) && (c[0].c2 < 0xa1 + 56)) {
	    E2alphabet_copy(n, E2greek_table[c[0].c2-0xa1], type);
	    return 1;
	} else {
	    E2alphabet_copy(n, "??", type);
	    return 1;
	}
      case 0xa7: /* 7\266\350\244\317\245\355\245\267\245\242\270\354\244\307\244\271 */
	E2alphabet_copy(n, "(Russia)", type);
	return 1;
      default:   /* 8\266\350\244\316\267\323\300\376\301\307\312\322\244\310\244\275\244\354\260\312\263\260\244\317\262\277\244\310\306\311\244\341\244\320\244\244\244\244\244\316\244\307\244\267\244\347\244\246\241\251 */
	E2alphabet_copy(n, "??", type);
	return 1;
    }
}

int E2a(c, n)
     Character *c;
     Character *n;
{
    return E2alphabet(c, n, ASCII);
}

int E2j(c, n)
     Character *c;
     Character *n;
{
    return E2alphabet(c, n, JISROMAN);
}
